@@ -20,12 +20,12 @@ AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
+# 调用交易服务发生异常。
+FAILEDOPERATION_CALLTRADE = 'FailedOperation.CallTrade'
+
 # CMQ 后台服务错误。
 FAILEDOPERATION_CMQBACKENDERROR = 'FailedOperation.CmqBackendError'
 
-# 创建vpc绑定关系失败。
-FAILEDOPERATION_CREATEBINDVPC = 'FailedOperation.CreateBindVpc'
-
 # 创建集群失败。
 FAILEDOPERATION_CREATECLUSTER = 'FailedOperation.CreateCluster'
 
@@ -86,6 +86,9 @@ FAILEDOPERATION_GETENVIRONMENTATTRIBUTESFAILED = 'FailedOperation.GetEnvironment
 # 获取主题分区数失败。
 FAILEDOPERATION_GETTOPICPARTITIONSFAILED = 'FailedOperation.GetTopicPartitionsFailed'
 
+# 实例尚未就绪，请稍后再试。
+FAILEDOPERATION_INSTANCENOTREADY = 'FailedOperation.InstanceNotReady'
+
 # 最大消息超过1MB。
 FAILEDOPERATION_MAXMESSAGESIZEERROR = 'FailedOperation.MaxMessageSizeError'
 
@@ -182,6 +185,9 @@ INVALIDPARAMETER_TOKENNOTFOUND = 'InvalidParameter.TokenNotFound'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 至少需要提供一个参数。
+INVALIDPARAMETERVALUE_ATLEASTONE = 'InvalidParameterValue.AtLeastOne'
+
 # 与现有集群名称重复。
 INVALIDPARAMETERVALUE_CLUSTERNAMEDUPLICATION = 'InvalidParameterValue.ClusterNameDuplication'
 
@@ -278,6 +284,9 @@ RESOURCENOTFOUND_ENVIRONMENTROLE = 'ResourceNotFound.EnvironmentRole'
 # 实例不存在。
 RESOURCENOTFOUND_INSTANCE = 'ResourceNotFound.Instance'
 
+# 迁移任务不存在。
+RESOURCENOTFOUND_MIGRATIONTASK = 'ResourceNotFound.MigrationTask'
+
 # 命名空间不存在。
 RESOURCENOTFOUND_NAMESPACE = 'ResourceNotFound.Namespace'
 
@@ -313,3 +322,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# 该实例不支持降配操作。
+UNSUPPORTEDOPERATION_INSTANCEDOWNGRADE = 'UnsupportedOperation.InstanceDowngrade'
